@@ -9,6 +9,7 @@ from pygame.transform import flip
 from pygame.draw import line
 from pygame.version import ver
 import math as mh
+import Ipygame as ipg
 
 ################################################## 1 蚁群算法路径规划 ###########################################
 
@@ -1021,7 +1022,7 @@ class ShanGeTu():
                     y_1 = (i+1)*self.line_size + i*self.cell_size
                     py.draw.rect(self.pic_backgroud,[0,0,0],[x_1,y_1,self.cell_size,self.cell_size])
 
-    def draw_way(self,way_data,_2D, y_x_change = False,new_pic = True,color = [0,0,0]):
+    def draw_way(self,way_data,_2D, y_x_change = False,new_pic = True,color = [0,0,0],line_type = '-'):
         '''
         '_2D':'标志输入量是否为[x,y]格式',
         'x_y_change': '调换x——y坐标',
@@ -1053,7 +1054,10 @@ class ShanGeTu():
             # 下面两行起到上下翻转的目的
             #point_1_y = self.backgroud_size - point_1_y
             #point_2_y = self.backgroud_size - point_2_y
-            py.draw.line(self.pic_shangetu,color,[point_1_x,point_1_y],[point_2_x,point_2_y],2)
+            if line_type == '-':
+                py.draw.line(self.pic_shangetu,color,[point_1_x,point_1_y],[point_2_x,point_2_y],2)
+            elif line_type == '--': 
+                ipg.dot_line(self.pic_shangetu,color,[point_1_x,point_1_y],[point_2_x,point_2_y],2)
                 
     def save(self,filename = '栅格图.jpg',reverse = False):
         '''
